A handle that allows reloading an ArcShift instance without having ‘mut’ access.
However, it does not implement Sync.
Structs
- ArcShift
Cell - ArcShiftCell is like an ArcShift, except that it can be reloaded without requiring ‘mut’-access. However, it is not ‘Sync’.
- ArcShift
Cell Handle - A handle to the pointed-to value of a ArcShiftCell. This handle should not be leaked, but if it is leaked, the effect is that whatever value the ArcShiftCell-instance pointed to at that time, will forever leak also. All the linked-list nodes from that entry and onward will also leak. So make sure to not leak the handle!
- Recursion
Detected - Error type representing the case that an operation was attempted from within a ‘get’-method closure.